@@ -1,10 +1,10 @@
+# flake8: noqa
 import json
 import logging
 import os
 import sys
 from io import BytesIO
 from io import StringIO
-from pathlib import Path
 
 import py
 import pytest
@@ -15,11 +15,13 @@ from pytest_benchmark.plugin import BenchmarkSession
 from pytest_benchmark.plugin import pytest_benchmark_compare_machine_info
 from pytest_benchmark.plugin import pytest_benchmark_generate_json
 from pytest_benchmark.plugin import pytest_benchmark_group_stats
+from pytest_benchmark.plugin import pytest_benchmark_scale_unit
 from pytest_benchmark.session import PerformanceRegression
 from pytest_benchmark.stats import normalize_stats
 from pytest_benchmark.storage.file import FileStorage
 from pytest_benchmark.utils import NAME_FORMATTERS
 from pytest_benchmark.utils import DifferenceRegressionCheck
+from pytest_benchmark.utils import Path
 from pytest_benchmark.utils import PercentageRegressionCheck
 from pytest_benchmark.utils import get_machine_id
 
@@ -29,7 +31,7 @@ pytest_plugins = "pytester"
 THIS = py.path.local(__file__)
 STORAGE = THIS.dirpath(THIS.purebasename)
 
-JSON_DATA = json.load(STORAGE.listdir('0030_*.json')[0].open())
+JSON_DATA = json.loads(STORAGE.listdir('0030_*.json')[0].read_text(encoding='utf8'))
 JSON_DATA["machine_info"] = {'foo': 'bar'}
 JSON_DATA["commit_info"] = {'foo': 'bar'}
 list(normalize_stats(bench['stats']) for bench in JSON_DATA["benchmarks"])
@@ -60,11 +62,18 @@ class MockSession(BenchmarkSession):
     def __init__(self, name_format):
         self.histogram = True
         self.verbose = False
+        self.quiet = False
         self.benchmarks = []
         self.performance_regressions = []
         self.sort = u"min"
         self.compare = '0001'
-        self.logger = logging.getLogger(__name__)
+        logger = logging.getLogger(__name__)
+        self.logger = Namespace(
+            debug=lambda *args, **_kwargs: logger.debug(*args),
+            info=lambda *args, **_kwargs: logger.info(*args),
+            warn=lambda *args, **_kwargs: logger.warn(*args),
+            error=lambda *args, **_kwargs: logger.error(*args),
+        )
         self.machine_id = "FoobarOS"
         self.machine_info = {'foo': 'bar'}
         self.save = self.autosave = self.json = False
@@ -73,11 +82,12 @@ class MockSession(BenchmarkSession):
             'min_rounds': 123,
             'min_time': 234,
             'max_time': 345,
-            'use_cprofile': False,
+            'cprofile': False,
         }
         self.cprofile_sort_by = 'cumtime'
         self.compare_fail = []
         self.config = Namespace(hook=Namespace(
+            pytest_benchmark_scale_unit=pytest_benchmark_scale_unit,
             pytest_benchmark_group_stats=pytest_benchmark_group_stats,
             pytest_benchmark_generate_machine_info=lambda **kwargs: {'foo': 'bar'},
             pytest_benchmark_update_machine_info=lambda **kwargs: None,
@@ -129,7 +139,7 @@ def force_bytes(text):
         return text
 
 
-@pytest.fixture(params=['short', 'normal', 'long'])
+@pytest.fixture(params=['short', 'normal', 'long', 'trial'])
 def name_format(request):
     return request.param
 
@@ -141,13 +151,8 @@ def sess(request, name_format):
 
 def make_logger(sess):
     output = StringIO()
-    sess.logger = Namespace(
-        warn=lambda code, text, **opts: output.write(u"%s: %s %s\n" % (code, force_text(text), opts)),
-        info=lambda text, **opts: output.write(force_text(text) + u'\n'),
-        error=lambda text: output.write(force_text(text) + u'\n'),
-    )
-    sess.storage.logger = Namespace(
-        warn=lambda code, text, **opts: output.write(u"%s: %s %s\n" % (code, force_text(text), opts)),
+    sess.logger = sess.storage.logger = Namespace(
+        warn=lambda text, **opts: output.write(force_text(text) + u'\n'),
         info=lambda text, **opts: output.write(force_text(text) + u'\n'),
         error=lambda text: output.write(force_text(text) + u'\n'),
     )
@@ -204,6 +209,12 @@ def test_regression_checks(sess, name_format):
             ('tests/test_normal.py::test_xfast_parametrized[0] (0001_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190343_uncommitted-changes)',
              "Field 'max' has failed DifferenceRegressionCheck: 0.000001843 > 0.000001000")
         ],
+        'trial': [
+            ('0001',
+             "Field 'stddev' has failed PercentageRegressionCheck: 23.331641765 > 5.000000000"),
+            ('0001',
+             "Field 'max' has failed DifferenceRegressionCheck: 0.000001843 > 0.000001000")
+        ],
     }[name_format]
     output = make_logger(sess)
     pytest.raises(PerformanceRegression, sess.check_regressions)
@@ -220,6 +231,10 @@ def test_regression_checks(sess, name_format):
         'long': """Performance has regressed:
 \ttests/test_normal.py::test_xfast_parametrized[0] (0001_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190343_uncommitted-changes) - Field 'stddev' has failed PercentageRegressionCheck: 23.331641765 > 5.000000000
 \ttests/test_normal.py::test_xfast_parametrized[0] (0001_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190343_uncommitted-changes) - Field 'max' has failed DifferenceRegressionCheck: 0.000001843 > 0.000001000
+""",
+        'trial': """Performance has regressed:
+\t0001 - Field 'stddev' has failed PercentageRegressionCheck: 23.331641765 > 5.000000000
+\t0001 - Field 'max' has failed DifferenceRegressionCheck: 0.000001843 > 0.000001000
 """
     }[name_format]
 
@@ -264,6 +279,12 @@ def test_regression_checks_inf(sess, name_format):
              '(0002_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190348_uncommitted-changes)',
              "Field 'max' has failed DifferenceRegressionCheck: 0.000005551 > "
              '0.000001000')
+        ],
+        'trial': [
+            ('0002',
+             "Field 'stddev' has failed PercentageRegressionCheck: inf > 5.000000000"),
+            ('0002',
+             "Field 'max' has failed DifferenceRegressionCheck: 0.000005551 > 0.000001000")
         ]
     }[name_format]
     output = make_logger(sess)
@@ -281,6 +302,10 @@ def test_regression_checks_inf(sess, name_format):
         'long': """Performance has regressed:
 \ttests/test_normal.py::test_xfast_parametrized[0] (0002_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190348_uncommitted-changes) - Field 'stddev' has failed PercentageRegressionCheck: inf > 5.000000000
 \ttests/test_normal.py::test_xfast_parametrized[0] (0002_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190348_uncommitted-changes) - Field 'max' has failed DifferenceRegressionCheck: 0.000005551 > 0.000001000
+""",
+        'trial': """Performance has regressed:
+\t0002 - Field 'stddev' has failed PercentageRegressionCheck: inf > 5.000000000
+\t0002 - Field 'max' has failed DifferenceRegressionCheck: 0.000005551 > 0.000001000
 """
     }[name_format]
 
@@ -297,15 +322,15 @@ def test_compare_1(sess, LineMatcher):
     ))
     print(output.getvalue())
     LineMatcher(output.getvalue().splitlines()).fnmatch_lines([
-        'BENCHMARK-C6: Benchmark machine_info is different. Current: {foo: "bar"} VS saved: {machine: "x86_64", node: "minibox", processor: "x86_64", python_compiler: "GCC 4.6.3", python_implementation: "CPython", python_version: "2.7.3", release: "3.13.0-55-generic", system: "Linux"}. {\'fslocation\': \'tests*test_storage\'}',
+        'Benchmark machine_info is different. Current: {foo: "bar"} VS saved: {machine: "x86_64", node: "minibox", processor: "x86_64", python_compiler: "GCC 4.6.3", python_implementation: "CPython", python_version: "2.7.3", release: "3.13.0-55-generic", system: "Linux"} (location: tests*test_storage).',
         'Comparing against benchmarks from: 0001_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190343_uncommitted'
         '-changes.json',
         '',
         '*------------------------------------------------------------------------ benchmark: 2 tests -----------------------------------------------------------------------*',
-        'Name (time in ns)               *      Min                 *Max                Mean              StdDev              Median                IQR            Outliers  Rounds  Iterations  OPS (Mops/s) *',
+        'Name (time in ns) * Min                 * Max                Mean              StdDev              Median                IQR            Outliers  Rounds  Iterations  OPS (Mops/s) *',
         '-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------*',
-        '*xfast_parametrized[[]0[]] (0001*)     217.3145 (1.0)      11*447.3891 (1.0)      262.2408 (1.00)     214.0442 (1.0)      220.1664 (1.00)     38.2154 (2.03)      90;1878    9987         418        3.8133 (1.00)*',
-        '*xfast_parametrized[[]0[]] (NOW) *     217.9511 (1.00)     13*290.0380 (1.16)     261.2051 (1.0)      263.9842 (1.23)     220.1638 (1.0)      18.8080 (1.0)      160;1726    9710         431        3.8284 (1.0)*',
+        '*0001* 217.3145 (1.0)      11*447.3891 (1.0)      262.2408 (1.00)     214.0442 (1.0)      220.1664 (1.00)     38.2154 (2.03)      90;1878    9987         418        3.8133 (1.00)*',
+        '*NOW*  217.9511 (1.00)     13*290.0380 (1.16)     261.2051 (1.0)      263.9842 (1.23)     220.1638 (1.0)      18.8080 (1.0)      160;1726    9710         431        3.8284 (1.0)*',
         '--------------------------------------------------------------------------------------------------------------------------------------------------------------------*',
         'Legend:',
         '  Outliers: 1 Standard Deviation from Mean; 1.5 IQR (InterQuartile Range) from 1st Quartile and 3rd Quartile.',
@@ -327,20 +352,21 @@ def test_compare_2(sess, LineMatcher):
     ))
     print(output.getvalue())
     LineMatcher(output.getvalue().splitlines()).fnmatch_lines([
-        'BENCHMARK-C6: Benchmark machine_info is different. Current: {foo: "bar"} VS saved: {machine: "x86_64", node: "minibox", processor: "x86_64", python_compiler: "GCC 4.6.3", python_implementation: "CPython", python_version: "2.7.3", release: "3.13.0-55-generic", system: "Linux"}. {\'fslocation\': \'tests*test_storage\'}',
+        'Benchmark machine_info is different. Current: {foo: "bar"} VS saved: {machine: "x86_64", node: "minibox", processor: "x86_64", python_compiler: "GCC 4.6.3", python_implementation: "CPython", python_version: "2.7.3", release: "3.13.0-55-generic", system: "Linux"} (location: tests*test_storage).',
         'Comparing against benchmarks from: 0002_b87b9aae14ff14a7887a6bbaa9731b9a8760555d_20150814_190348_uncommitted-changes.json',
         '',
         '*------------------------------------------------------------------------ benchmark: 2 tests -----------------------------------------------------------------------*',
-        'Name (time in ns)            *         Min                 *Max                Mean              StdDev              Median                IQR            Outliers  Rounds  Iterations  OPS (Mops/s)*',
+        'Name (time in ns) * Min                 *Max                Mean              StdDev              Median                IQR            Outliers  Rounds  Iterations  OPS (Mops/s)*',
         '--------------------------------------------------------------------------------------------------------------------------------------------------------------------*',
-        '*xfast_parametrized[[]0[]] (0002*)     216.9028 (1.0)       7*739.2997 (1.0)      254.0585 (1.0)        0.0000 (1.0)      219.8103 (1.0)      27.3309 (1.45)     235;1688   11009         410        3.9361 (1.0)*',
-        '*xfast_parametrized[[]0[]] (NOW) *     217.9511 (1.00)     13*290.0380 (1.72)     261.2051 (1.03)     263.9842 (inf)      220.1638 (1.00)     18.8080 (1.0)      160;1726    9710         431        3.8284 (0.97)*',
+        '*0002* 216.9028 (1.0)       7*739.2997 (1.0)      254.0585 (1.0)        0.0000 (1.0)      219.8103 (1.0)      27.3309 (1.45)     235;1688   11009         410        3.9361 (1.0)*',
+        '*NOW*  217.9511 (1.00)     13*290.0380 (1.72)     261.2051 (1.03)     263.9842 (inf)      220.1638 (1.00)     18.8080 (1.0)      160;1726    9710         431        3.8284 (0.97)*',
         '--------------------------------------------------------------------------------------------------------------------------------------------------------------------*',
         'Legend:',
         '  Outliers: 1 Standard Deviation from Mean; 1.5 IQR (InterQuartile Range) from 1st Quartile and 3rd Quartile.',
         '  OPS: Operations Per Second, computed as 1 / Mean',
     ])
 
+
 @freeze_time("2015-08-15T00:04:18.687119")
 def test_save_json(sess, tmpdir, monkeypatch):
     monkeypatch.setattr(plugin, '__version__', '2.5.0')
@@ -365,7 +391,7 @@ def test_save_with_name(sess, tmpdir, monkeypatch):
     files = list(Path(str(tmpdir)).rglob('*.json'))
     print(files)
     assert len(files) == 1
-    assert json.load(files[0].open('rU')) == JSON_DATA
+    assert json.loads(files[0].read_text(encoding='utf8')) == JSON_DATA
 
 
 @freeze_time("2015-08-15T00:04:18.687119")
@@ -379,7 +405,7 @@ def test_save_no_name(sess, tmpdir, monkeypatch):
     sess.handle_saving()
     files = list(Path(str(tmpdir)).rglob('*.json'))
     assert len(files) == 1
-    assert json.load(files[0].open('rU')) == JSON_DATA
+    assert json.loads(files[0].read_text(encoding='utf8')) == JSON_DATA
 
 
 @freeze_time("2015-08-15T00:04:18.687119")
@@ -395,7 +421,7 @@ def test_save_with_error(sess, tmpdir, monkeypatch):
     sess.handle_saving()
     files = list(Path(str(tmpdir)).rglob('*.json'))
     assert len(files) == 1
-    assert json.load(files[0].open('rU')) == {
+    assert json.loads(files[0].read_text(encoding='utf8')) == {
         'benchmarks': [],
         'commit_info': {'foo': 'bar'},
         'datetime': '2015-08-15T00:04:18.687119',
@@ -415,4 +441,4 @@ def test_autosave(sess, tmpdir, monkeypatch):
     sess.handle_saving()
     files = list(Path(str(tmpdir)).rglob('*.json'))
     assert len(files) == 1
-    assert json.load(files[0].open('rU')) == JSON_DATA
+    assert json.loads(files[0].read_text(encoding='utf8')) == JSON_DATA
